@@ -93,6 +93,7 @@ class Setup(object):
         for device in devices:
             if device['subtype'] == 'CONTACT':
                 contact_device = ContactDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -105,12 +106,13 @@ class Setup(object):
                     subtype=device['subtype'],
                     warnings=device['warnings'],
                     zone_type=device['zone_type'],
-                    location=device['traits']['location']['name'].capitalize(),
-                    soak=device['traits']['soak']['enabled'],
+                    location=device['traits']['location']['name'].capitalize() if 'location' in device['traits'] else None,
+                    soak=device['traits']['soak']['enabled'] if 'soak' in device['traits'] else False,
                 )
                 device_list.append(contact_device)
             elif device['subtype'] == 'MOTION_CAMERA':
                 contact_device = CameraDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -123,13 +125,14 @@ class Setup(object):
                     subtype=device['subtype'],
                     warnings=device['warnings'],
                     zone_type=device['zone_type'],
-                    location=device['traits']['location']['name'].capitalize(),
-                    soak=device['traits']['soak']['enabled'],
-                    vod=device['traits']['vod'],
+                    location=device['traits']['location']['name'].capitalize() if 'location' in device['traits'] else None,
+                    soak=device['traits']['soak']['enabled'] if 'soak' in device['traits'] else False,
+                    vod=device['traits']['vod'] if 'vod' in device['traits'] else None,
                 )
                 device_list.append(contact_device)
             elif device['subtype'] == 'SMOKE':
                 contact_device = SmokeDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -142,12 +145,13 @@ class Setup(object):
                     subtype=device['subtype'],
                     warnings=device['warnings'],
                     zone_type=device['zone_type'],
-                    location=device['traits']['location']['name'].capitalize(),
-                    soak=device['traits']['soak']['enabled'],
+                    location=device['traits']['location']['name'].capitalize() if 'location' in device['traits'] else None,
+                    soak=device['traits']['soak']['enabled'] if 'soak' in device['traits'] else False,
                 )
                 device_list.append(contact_device)
             elif device['subtype'] == 'BASIC_KEYFOB':
                 contact_device = KeyFobDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -160,12 +164,13 @@ class Setup(object):
                     subtype=device['subtype'],
                     warnings=device['warnings'],
                     zone_type=device['zone_type'],
-                    owner_id=device['traits']['owner']['id'],
-                    owner_name=device['traits']['owner']['name'],
+                    owner_id=device['traits']['owner']['id'] if 'owner' in device['traits'] else None,
+                    owner_name=device['traits']['owner']['name'] if 'owner' in device['traits'] else None,
                 )
                 device_list.append(contact_device)
             elif device['device_type'] == 'GSM':
                 contact_device = GSMDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -178,11 +183,12 @@ class Setup(object):
                     subtype=device['subtype'],
                     warnings=device['warnings'],
                     zone_type=device['zone_type'],
-                    signal_level=device['traits']['signal_level']['level'],
+                    signal_level=device['traits']['signal_level']['level'] if 'signal_level' in device['traits'] else None,
                 )
                 device_list.append(contact_device)
             elif device['device_type'] == 'PGM':
                 contact_device = PGMDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -195,12 +201,13 @@ class Setup(object):
                     subtype=device['subtype'],
                     warnings=device['warnings'],
                     zone_type=device['zone_type'],
-                    parent_id=device['traits']['parent']['id'],
-                    parent_port=device['traits']['parent']['port'],
+                    parent_id=device['traits']['parent']['id'] if 'parent' in device['traits'] else None,
+                    parent_port=device['traits']['parent']['port'] if 'parent' in device['traits'] else None,
                 )
                 device_list.append(contact_device)
             else:
                 generic_device = GenericDevice(
+                    bypass=device['traits']['bypass']['enabled'] if 'bypass' in device['traits'] else False,
                     device_number=device['device_number'],
                     device_type=device['device_type'],
                     enrollment_id=device['enrollment_id'],
@@ -215,7 +222,6 @@ class Setup(object):
                     zone_type=device['zone_type'],
                 )
                 device_list.append(generic_device)
-
         return device_list
 
     def get_events(self, timestamp_hour_offset=2):
@@ -412,6 +418,10 @@ class Setup(object):
         """ Complete the password reset by entering the reset code received in the email and a new password. """
         return self.__api.password_reset_complete(reset_password_code, new_password)['user_token']
 
+    def set_bypass_zone(self, zone, set_enabled):
+        """ Enabled or disable zone bypassing (for example, bypass a sensor to disable it). """
+        return self.__api.set_bypass_zone(zone, set_enabled)['process_token']
+
     def set_name_user(self, user_id, name):
         """ Set the name of a user by user ID. """
         return self.__api.set_name('USER', user_id, name)['process_token']
